Learn R Programming

ecorisk (version 0.3.1)

ecorisk-package: ecorisk: Risk Assessments for Ecosystems or Ecosystem Components

Description

Implementation of a modular framework for ecosystem risk assessments, combining existing risk assessment approaches tailored to semi-quantitative and quantitative analyses.

Arguments

Author

Maintainer: Helene Gutte helenegutte96@gmail.com (ORCID) [copyright holder]

Authors:

See Also