This Baltic Sea demo dataset contains expert-assigned scores for five
environmental and anthropogenic pressures, detailing individual exposure
components and their associated uncertainties. The dataset was initialized
using the template function create_template_exposure.
ex_expert_exposureA data frame with 5 observations and 9 variables (values randomly assigned).
Environmental or anthropogenic pressure.
Score for the magnitude pressure change.
Score for the frequency or duration of pressure effect.
Score for the future trend of pressure.
Score for the spatial extent of pressure change.
Uncertainty of magnitude score.
Uncertainty of frequency score.
Uncertainty of trend score.
Uncertainty of spatial extent score.
Exposure scores range from 1 (low) to 5 (high), while uncertainties range
from 1 (low) to 3 (high). This dataset can be used as input for the function
calc_exposure.