aggregate_risk() function based on expert scoresThis is an expert-based example output from the aggregate_risk function
applied to the ex_output_risk_expert demo data.
ex_output_aggregate_risk_expertA list of three data frames.
A data frame with 30 rows and 5 columns, containing the multi-indicator risk and uncertainty of each pressure per type and pathway.
A data frame with 24 rows and 5 columns, containing the multi-pressure risk and uncertainty on each indicator per type and pathway.
A data frame with 6 rows and 4 columns, containing the aggregated ecosystem risk and uncertainty per type and pathway.