aggregate_risk() function based on modelled scoresThis dataset provides example output from the aggregate_risk function,
applied to the ex_output_risk_model demo data, following the modelling
pathway.
ex_output_aggregate_risk_modelA list of three data frames.
A data frame with 32 rows and 5 variables, containing the multi-indicator risk and uncertainty of each pressure per type and pathway.
A data frame with 8 rows and 5 variables, containing the multi-pressure risk and uncertainty on each indicator per type and pathway.
A data frame with 4 rows and 4 variables, containing the aggregated ecosystem risk and uncertainty per type and pathway.