model_exposure() function based on time seriesThis dataset provides example output from the model_exposure function,
with component-specific exposure scores derived from the pressure time series
in pressure_ts_baltic. These scores are combined into an
overall exposure score, with associated uncertainties derived from two model types.
ex_output_model_exposureA data frame with 8 observations and 10 variables.
Names of the assessed pressure.
Combined exposure score (1 to 5).
Uncertainty score from exposure modelling (1 to 3).
Score for the magnitude or degree of change (1 to 5).
Score for the frequency or duration of change (1 to 5).
Score for the current trend of change (1 to 5).
Direction of the trend slope (increase or decrease).
Score for spatial extent of the pressure (default: 3; user-defined: 1 to 5).
Uncertainty score based on an ARIMA model.
Uncertainty score based on a GAM model.
Mean of the baseline conditions, used for magnitude scoring.
Mean of the current conditions, used for magnitude and frequency scoring.
Standard deviations of the baseline conditions. Used for scoring of magnitude and frequency.
Slope of the linear model used for scoring the future trend and to determine the direction.
P-value of the linear model, used to score the future trend.