status() functionThis dataset provides example output from the status function,
applied to four Baltic Sea indicator time series provided in indicator_ts_baltic.
ex_output_statusA data frame with 2 rows and 3 variables.
Name of the assessed indicator.
Qualitative description of the current status compared to the threshold.
Score used in the risk function to calculate risk from vulnerability and status.