Time series of two marine indicators covering the period 1984–2016 in the
Eastern Baltic Sea (data altered from original time series). This dataset
serves as a demo input in the model_sensitivity and
model_exposure functions.
indicator_ts_balticA data frame with 33 observations and 3 variables.
Time variable.
Mean size of zooplankton (in wet weight micrograms).
Mean spawning stock biomass of eastern Baltic cod (units unspecified).