Time series of eight environmental and anthropogenic pressures potentially affecting
the zooplankton mean size or cod spawning stock biomass in the Eastern Baltic Sea.
The time series cover the period 1984–2016 (data altered from original time series).
This dataset serves as a demo input in the model_exposure and
model_sensitivity functions.
pressure_ts_balticA data frame with 33 observations and 9 variables.
Time variable.
Mean total nitrogen input into the Baltic Sea per year.
Mean total phosphorus input into the Baltic Sea per year.
Mean sea surface temperature in summer in the Baltic Sea per year (in °C).
Mean sea bottom temperature in the Baltic Sea per year (in °C).
Mean sea surface salinity in summer in the Baltic Sea per year.
Mean sea bottom salinity in the Baltic Sea per year.
Mean bottom oxygen concentration in the Baltic Sea per year (in mg/m^3).
Mean eastern Baltic cod fishing pressure per year.