Time series of three environmental and anthropogenic pressures in the North Sea covering the period 1970–2020 (data altered from original time series). This dataset serves as internal test data.
pressure_ts_northseaA data frame with 33 observations and 9 variables.
Time variable.
Mean sea bottom temperature in the Baltic Sea per year (in °C).
Mean sea bottom salinity in the Baltic Sea per year.
Mean eastern Baltic cod fishing pressure per year.