aggregate_risk() function based on modelled scoresThis dataset provides example output from the risk function,
applied to the ex_output_vulnerability_model and ex_output_status
demo datasets, following the modelling pathway.
ex_output_risk_modelA data frame with 16 observations and 8 variables.
Name of the assessed indicator.
Name of the assessed pressure.
Type of effect (always direct + indirect for modelling pathway).
Pathway used for the exposure and sensitivity assessment.
Vulnerability score.
Qualitative descriptor of the current status of the indicator.
Risk score.
Uncertainty score associated with the vulnerability component scoring.